@@ -1,3 +1,25 @@
+/* postscript.c
+ *
+ * Copyright (C) 2008 Till Kamppeter <till.kamppeter@gmail.com>
+ * Copyright (C) 2008 Lars Uebernickel <larsuebernickel@gmx.de>
+ *
+ * This file is part of foomatic-rip.
+ *
+ * Foomatic-rip is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * Foomatic-rip is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the
+ * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Boston, MA 02111-1307, USA.
+ */
 
 #include "foomaticrip.h"
 #include "util.h"
@@ -728,7 +750,7 @@ void _print_ps(stream_t *stream)
                             if (spooler == SPOOLER_CUPS &&
                                 linetype == LT_BEGIN_FEATURE &&
                                 !option_get_value(o, optionset("notfirst")) &&
-                                strcmp(option_get_value(o, optset), value) != 0 &&
+				strcmp(option_get_value(o, optset) ?: "", value) != 0 &&
                                 (inheader || option_get_section(o) == SECTION_PAGESETUP)) {
 
                                 /* We have the first occurence of an option
